@@ -1,6 +1,6 @@
 package Zabbix::Reporter::Web;
 {
-  $Zabbix::Reporter::Web::VERSION = '0.06';
+  $Zabbix::Reporter::Web::VERSION = '0.07';
 }
 BEGIN {
   $Zabbix::Reporter::Web::AUTHORITY = 'cpan:TEX';
@@ -275,12 +275,28 @@ sub _handle_request {
         }
     } ## end if ( $mode && $self->plugins...)
     else {
-        return [ 400, [ 'Content-Type', 'text/plain' ], ['Bad Request - Command not found'] ];
+        return [ 400, [ 'Content-Type', 'text/html' ], [$self->_list_plugins()] ];
     }
 
     return 1;
 } ## end sub _handle_request
 
+sub _list_plugins {
+  my $self = shift;
+  my $request = shift;
+
+  my $body = '<html><body><h1>Bad Request - Command not found</h1><h2>Available Plugins</h2><ul>';
+  try {
+    foreach my $plugin (sort keys %{ $self->plugins() } ) {
+      my $alias = $self->plugins->{$plugin}->alias();
+      $body .= '<li><a href="?mode='.$alias.'">'.$plugin.'</a>';
+    }
+  };
+  $body .= '</ul></body></html>';
+
+  return $body;
+}
+
 sub _log_request {
     my $self        = shift;
     my $request_ref = shift;
